@@ -5,14 +5,9 @@
 #define BUILDINFO_H
 
     #undef ERROR
+    #define R_NO_REMAP // https://rstudio.github.io/r-manuals/r-exts/The-R-API.html
     #include <R.h>
 
-    // for windows and Mac build need to undo declarations in R.h (R>1.8.0)
-    //#ifdef IEEE_754
-    //#undef ISNAN
-    //#define ISNAN(x)   R_IsNaNorNA(x)
-    //#endif
-
     #define GBM_FAILED(hr) ((unsigned long)hr != 0)
     typedef unsigned long GBMRESULT;
     #define GBM_OK 0
@@ -30,4 +25,3 @@
     // #define NOISY_DEBUG
 
 #endif // BUILDINFO_H
-
